@@ -21,6 +21,7 @@ Validators = List[Dict]
 Env = Dict[Text, Any]
 Extra = List[Text]
 SetUp = List[Text]
+Execute = List[Text]
 TearDown = List[Text]
 
 
@@ -80,6 +81,7 @@ class TStep(BaseModel):
     validators: Validators = Field([], alias="validate")
     validate_script: List[Text] = []
     setup: SetUp = []
+    execute: Execute = []
     teardown: TearDown = []
 
 
@@ -91,6 +93,7 @@ class TestCase(BaseModel):
 class ProjectMeta(BaseModel):
     debugtalk_py: Text = ""  # debugtalk.py file content
     debugtalk_path: Text = ""  # debugtalk.py file path
+    custom_path: Text = ""  # custom.py file path
     dot_env_path: Text = ""  # .env file path
     functions: FunctionsMapping = {}  # functions defined in debugtalk.py
     env: Env = {}
@@ -209,3 +212,17 @@ class TestSuiteSummary(BaseModel):
     time: TestCaseTime = TestCaseTime()
     platform: PlatformInfo
     testcases: List[TestCaseSummary]
+
+
+class DataCorrelationEnum(BaseModel):
+    MYSQL: Text = "mysql"
+    REDIS: Text = "redis"
+    MONGO: Text = "mongo"
+    CMD: Text = "cmd"
+    VAR_SYMBOL: Text = "##"
+    DB_CONFIG_SYMBOL: Text = "&&db:"
+    SUPPORT_TYPES: List = [MYSQL, REDIS, MONGO]
+
+
+# 单例
+data_enum = DataCorrelationEnum()
