@@ -221,10 +221,6 @@ class HttpRunner(object):
         resp_obj = ResponseObject(resp)
         step.variables["response"] = resp_obj
 
-        # teardown hooks
-        if step.teardown_hooks:
-            self.__call_hooks(step.teardown_hooks, step.variables, "teardown request")
-
         def log_req_resp_details():
             err_msg = "\n{} DETAILED REQUEST & RESPONSE {}\n".format("*" * 32, "*" * 32)
 
@@ -236,10 +232,10 @@ class HttpRunner(object):
             err_msg += f"headers: {headers}\n"
             for k, v in parsed_request_dict.items():
                 v = utils.omit_long_data(v)
-                if isinstance(v, str):
+                if isinstance(v, Text):
                     v = unquote(v)
-                if isinstance(v, dict):
-                    v = {k: unquote(v) for k, v in v.items() if isinstance(v, str)}
+                if isinstance(v, Dict):
+                    v = {k: unquote(v) for k, v in v.items() if isinstance(v, Text)}
                 err_msg += f"{k}: {repr(v)}\n"
 
             err_msg += "\n"
@@ -258,9 +254,6 @@ class HttpRunner(object):
 
         variables_mapping = step.variables
         variables_mapping.update(extract_mapping)
-        # 执行teardown
-        if step.teardown:
-            self.__execute("teardown", step, variables_mapping, self.__project_meta.functions)
 
         # validate
         validators = step.validators
@@ -289,6 +282,13 @@ class HttpRunner(object):
                 # save step data
                 step_data.data = self.__session.data
 
+        # teardown hooks
+        if step.teardown_hooks:
+            self.__call_hooks(step.teardown_hooks, step.variables, "teardown request")
+
+        # 执行teardown
+        if step.teardown:
+            self.__execute("teardown", step, variables_mapping, self.__project_meta.functions)
         return step_data
 
     def __run_step_testcase(self, step: TStep) -> StepData:
