@@ -8,6 +8,7 @@ import re
 import uuid
 from multiprocessing import Queue
 from typing import Dict, List, Any, Text, NoReturn, Union
+from urllib.parse import quote, unquote
 
 import sentry_sdk
 from loguru import logger
@@ -317,6 +318,10 @@ def execute_redis(rd: Union[Text, Dict, List], cli: Text) -> Any:
         del_func = ["del(", "hdel(", "delete(", "hash_del("]
         return any(parsed_string.lower().startswith(func) is True for func in del_func)
 
+    def is_exists():
+        exists_func = ["exists("]
+        return any(parsed_string.lower().startswith(func) is True for func in exists_func)
+
     def execute(config, content):
         handler = RedisHandler(config)
         if parsed_string.lower().startswith("get("):
@@ -336,7 +341,7 @@ def execute_redis(rd: Union[Text, Dict, List], cli: Text) -> Any:
         elif parsed_string.lower().startswith("clean") and parsed_string != "clean_redis":
             return handler.clean_redis
         else:
-            scope = {'handler': RedisHandler(rd)}
+            scope = {'handler': RedisHandler(config)}
             cli = "handler." + parsed_string
             return eval(cli, scope)
 
@@ -352,11 +357,23 @@ def execute_redis(rd: Union[Text, Dict, List], cli: Text) -> Any:
             if is_get() is True:
                 if value is not None:
                     return value
+                elif data_source.index(v) == len(data_source) - 1 and value is None:
+                    return None
             if is_del() is True:
                 if value == 1:  # delete success
-                    return None
+                    logger.debug(f"在{v}中删除成功")
+                    return 1
+                elif data_source.index(v) == len(data_source) - 1 and value == 0:
+                    return 0
+            if is_exists() is True:
+                if value == 1:
+                    logger.debug(f"在{v}中存在key:{content}")
+                    return value
+                elif data_source.index(v) == len(data_source) - 1 and value == 0:
+                    return 0
             else:
                 return value
+
     else:
         return execute(data_source, content)
 
@@ -388,3 +405,26 @@ def remove_bracket_first(word):
     right = word[data2 + 1:]
     word = left + right
     return word
+
+
+def quote_dict(content: Dict):
+    for k, v in content.items():
+        if isinstance(v, Text):
+            content[k] = quote(v)
+        else:
+            content[k] = v
+    return content
+
+
+def unquote_dict(value: Union[Text, Dict]):
+    if isinstance(value, Text):
+        return unquote(value)
+    if isinstance(value, Dict):
+        for k, v in value.items():
+            if isinstance(v, Text):
+                value[k] = unquote(v)
+            else:
+                value[k] = unquote_dict(v)
+        return value
+    else:
+        return value
